@@ -163,7 +163,10 @@ void UpdaterWindow::workerEvent(QApt::WorkerEvent event)
         break;
     case QApt::CacheUpdateFinished:
     case QApt::CommitChangesFinished:
-        reload();
+        if (m_backend) {
+            reload();
+            setActionsEnabled();
+        }
     case QApt::PackageDownloadFinished:
         returnFromPreview();
         if (m_warningStack.size() > 0) {
@@ -205,6 +208,7 @@ void UpdaterWindow::errorOccurred(QApt::ErrorCode error, const QVariantMap &args
         if (m_downloadWidget) {
             m_downloadWidget->clear();
         }
+    case QApt::AuthError:
         m_updaterWidget->setEnabled(true);
         QApplication::restoreOverrideCursor();
         returnFromPreview();
@@ -273,9 +277,6 @@ void UpdaterWindow::returnFromPreview()
 {
     m_stack->setCurrentWidget(m_updaterWidget);
     m_backend->markPackagesForDistUpgrade();
-
-    // We may not have anything to preview; check.
-    setActionsEnabled();
 }
 
 void UpdaterWindow::setActionsEnabled(bool enabled)
